@@ -8,7 +8,7 @@ from multidecoder.decoders.base64 import pad_base64
 from multidecoder.node import Node
 from multidecoder.registry import decoder
 
-CMD_RE = rb"(?i)\bc\^?m\^?d\^?\b[^)\x00]*"
+CMD_RE = rb'(?i)("(?:C:\\WINDOWS\\system32\\)?\bcmd(?:.exe)?"|(?:C:\\Windows\\System32\\)?\bc\^?m\^?d\b)[^\x00]*'
 POWERSHELL_INDICATOR_RE = (
     rb'(?i)(?:^|/c|/k|/r|[\s;,=&\'"])?\b(\^?p\^?(?:o\^?w\^?e\^?r\^?s\^?h\^?e\^?l\^?l|w\^?s\^?h))\b'
 )
@@ -53,21 +53,31 @@ def deobfuscate_cmd(cmd: bytes) -> tuple[bytes, str]:
 def find_cmd_strings(data: bytes) -> list[Node]:
     cmd_strings = []
     for match in re.finditer(CMD_RE, data):
-        if match.group().lower().strip() not in (b"cmd", b"cmd.exe"):
-            deobfuscated, obfuscation = deobfuscate_cmd(match.group())
+        full_cmd = match.group()
+        start, end = match.span()
+        parens = 0
+        for i, char in enumerate(full_cmd):
+            if char == ord(b")"):
+                parens -= 1
+            elif char == ord(b"("):
+                parens += 1
+            if parens < 0:
+                full_cmd = full_cmd[:i]
+                end = start + i
+        deobfuscated, obfuscation = deobfuscate_cmd(full_cmd)
 
-            split = deobfuscated.split()
+        split = deobfuscated.split()
 
-            # The cmd binary/command itself is at split[0]
-            if (not split[0].startswith(b'"') and split[0].endswith(b'"')) or (
-                not split[0].startswith(b"'") and split[0].endswith(b"'")
-            ):
-                # Remove the trailing quotation
-                split[0] = split[0][:-1]
-                deobfuscated = b" ".join(split)
+        # The cmd binary/command itself is at split[0]
+        if (not split[0].startswith(b'"') and split[0].endswith(b'"')) or (
+            not split[0].startswith(b"'") and split[0].endswith(b"'")
+        ):
+            # Remove the trailing quotation
+            split[0] = split[0][:-1]
+            deobfuscated = b" ".join(split)
 
-            cmd_string = Node("shell.cmd", deobfuscated, obfuscation, *match.span())
-            cmd_strings.append(cmd_string)
+        cmd_string = Node("shell.cmd", deobfuscated, obfuscation, start, end)
+        cmd_strings.append(cmd_string)
     return cmd_strings
 
 
@@ -171,4 +181,10 @@ def get_cmd_command(cmd: bytes) -> bytes:
 
 def get_powershell_command(powershell: bytes) -> bytes:
     match = re.match(POWERSHELL_ARGS_RE, powershell)
-    return powershell[match.end() :] if match else powershell
+    if not match:
+        return powershell
+    command = powershell[match.end() :]
+    # Strip if the command starts and end with a double quote (34) or single quote (39)
+    if len(command) > 1 and command[0] in [34, 39] and command[0] == command[-1]:
+        command = command[1:-1]
+    return command
